| Title: | Companion Package for WSBIM1322 Course |
|---|---|
| Description: | Companion package for the WSBIM1322 course, distributing data and general documentation, and making course administration easier. |
| Authors: | Laurent Gatto [aut, cre] (ORCID: <https://orcid.org/0000-0002-1520-2268>), Julie Devis [ctb] (ORCID: <https://orcid.org/0000-0001-5525-5666>) |
| Maintainer: | Laurent Gatto <[email protected]> |
| License: | GPL-2 |
| Version: | 0.3.2 |
| Built: | 2026-05-28 14:53:40 UTC |
| Source: | https://github.com/UCLouvain-CBIO/rWSBIM1322 |
The data stems from the 6th study of the Clinical Proteomic Technology Assessment for Cancer (CPTAC). The authors spiked the Sigma Universal Protein Standard mixture 1 (UPS1) containing 48 different human proteins in a protein background of 60 ng/microL Saccharomyces cerevisiae strain BY4741. Two different spike-in concentrations were used: 6A (0.25 fmol UPS1 proteins/microL) and 6B (0.74 fmol UPS1 proteins/microL). In this subset, we limited ourselves to the data of LTQ-Orbitrap W at site 56. The data were searched with MaxQuant version 1.5.2.8, and detailed search settings were described in Goeminne et al. (2016). Three replicates peptide quantitation data are available for each concentration.
cptac_secptac_se
An object of class SummarizedExperiment with 4051 rows and 6 columns.
The data are available as SummarizedExperiment objects.
See the proteomics tutorial from the Bioinformatics Summer School 2019 (https://lgatto.github.io/bioc-ms-prot/bss-lab.html) for scripts on how these data were processed.
library("SummarizedExperiment") data(cptac_se) cptac_se data(cptac_se_prot) cptac_se_protlibrary("SummarizedExperiment") data(cptac_se) cptac_se data(cptac_se_prot) cptac_se_prot
This is a small toy example providing expression values for 5 genes and three samples from Olga Vitek. It is used to compare euclidean and correlation distances and the effect/importance of scaling.
g3g3
An object of class matrix (inherits from array) with 3 rows and 5 columns.
data(g3) g3 matplot(t(g3), type = "b", xlab = "Samples", ylab = "Expression")data(g3) g3 matplot(t(g3), type = "b", xlab = "Samples", ylab = "Expression")
This data is a copy of the iris data, reframed for biomedical
course. It illustrates the expression of 4 genes, BRCA1, BRCA2,
TP53 and A1CF, in 150 patients, that have been categorised in 3
catégories, A, B and C.
girisgiris
An object of class data.frame with 150 rows and 5 columns.
head(giris) pairs(giris, col = giris$GRADE) pca2 <- prcomp(giris2[, -5], scale = TRUE) factoextra::fviz_pca_ind(pca2, col.ind = giris2$GRADE)head(giris) pairs(giris, col = giris$GRADE) pca2 <- prcomp(giris2[, -5], scale = TRUE) factoextra::fviz_pca_ind(pca2, col.ind = giris2$GRADE)
The is a subset of the full Hiiragi 2013 dataset from the
Hiiragi2013 package. The data describes cell-to-cell expression
variability followed by signal reinforcement progressively segregates
early mouse lineages.
data("hiiragi2013df1") data("hiiragi2013df2")data("hiiragi2013df1") data("hiiragi2013df2")
The data originally come from the Hiiragi2013 Bioconductor
package. See inst/script/hiiragi2013.R to see how they have
been converted.
Cell-to-cell expression variability followed by signal reinforcement progressively segregates early mouse lineages by Y. Ohnishi, W. Huber, A. Tsumura, M. Kang, P. Xenopoulos, K. Kurimoto, A. K. Oles, M. J. Arauzo-Bravo, M. Saitou, A.-K. Hadjantonakis and T. Hiiragi; Nature Cell Biology (2014) 16(1): 27-37. doi: 10.1038/ncb2881.
data(hiiragi2013df1) data(hiiragi2013df2)data(hiiragi2013df1) data(hiiragi2013df2)
This is a small RNA-Seq data set, build from the data returned by
the rWSBIM1207::kem2.tsv() function.
kem2_sekem2_se
An object of class SummarizedExperiment with 4774 rows and 16 columns.
library("SummarizedExperiment") data(kem2_se) assay(kem2_se) colData(kem2_se) rowData(kem2_se)library("SummarizedExperiment") data(kem2_se) assay(kem2_se) colData(kem2_se) rowData(kem2_se)
Generate data
make_data(noma)make_data(noma)
noma |
'character(1)' that can be coerced into a numeric |
A SummarizedExperimet
make_data("123")make_data("123")
This data comes from the Modern Statistics for Modern Biology book and was
originally called mat1 from the mat1xcms.RData file. It contains
quantitation data for 399 metabolites and 6 knock-out and 6 wild-type
samples.
metab1metab1
An object of class matrix (inherits from array) with 399 rows and 12 columns.
data(metab1) dim(metab1) metab1[1:10, 1:3]data(metab1) dim(metab1) metab1[1:10, 1:3]
Several SummarizedExperiment datasets for the recap exercices in
the conclusion chapter of the course.
recapSE1recapSE1
An object of class SummarizedExperiment with 1550 rows and 20 columns.
data(recapSE1) recapSE1 data(recapSE2) recapSE2data(recapSE1) recapSE1 data(recapSE2) recapSE2
Package version
rWSBIM1322version()rWSBIM1322version()
## check the package version that is currently installed rWSBIM1322version()## check the package version that is currently installed rWSBIM1322version()
See scripts/randata.R for how these data were generated.
tdata1tdata1
An object of class matrix (inherits from array) with 100 rows and 6 columns.
data(tdata1) head(tdata1) data(tdata2) tdata2 data(tdata3) tdata3 data(tdata4) tdata4data(tdata1) head(tdata1) data(tdata2) tdata2 data(tdata3) tdata3 data(tdata4) tdata4
A character vector with Uniprot identifiers.
data("up_selected")data("up_selected")
data(up_selected) head(up_selected)data(up_selected) head(up_selected)
See man/xy.R for how these data were generated. xy is scaled,
xy0 is the orginal data.
xyxy
An object of class data.frame with 20 rows and 2 columns.
data(xy) xy0 xy pca <- prcomp(xy) summary(pca) plot(pca) biplot(pca)data(xy) xy0 xy pca <- prcomp(xy) summary(pca) plot(pca) biplot(pca)